@@ -36,7 +36,7 @@ setMethod("TSconnect",   signature(drv="MySQLDriver", dbname="character"),
           stop("Database ",dbname," does not appear to be a TS database.")
 	  }
 	new("TSMySQLConnection" , con, drv="MySQL", dbname=dbname, 
-  	       hasVintages=dbExistsTable(con, "vintages"), 
+  	       hasVintages=dbExistsTable(con, "vintageAlias"), 
   	       hasPanels  =dbExistsTable(con, "panels")) 
 	})
 
@@ -46,7 +46,7 @@ setMethod("TSput",   signature(x="ANY", serIDs="character", con="MySQLConnection
        vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
     TSdbi:::TSputSQL(x, serIDs, con, Table=Table, 
        TSdescription.=TSdescription., TSdoc.=TSdoc.,  TSlabel.=TSlabel.,
-       vintage=vintage, panel=panel,...) )
+       vintage=vintage, panel=panel) )
 
 setMethod("TSget",   signature(serIDs="character", con="MySQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"), 
@@ -57,27 +57,28 @@ setMethod("TSget",   signature(serIDs="character", con="MySQLConnection"),
     TSdbi:::TSgetSQL(serIDs, con, TSrepresentation=TSrepresentation,
        tf=tf, start=start, end=end,
        names=names, TSdescription=TSdescription, TSdoc=TSdoc, TSlabel=TSlabel,
-       vintage=vintage, panel=panel, ...) )
+       vintage=vintage, panel=panel) )
 
 setMethod("TSdates",    signature(serIDs="character", con="MySQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"),  
        vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
-     TSdbi:::TSdatesSQL(serIDs, con, vintage=vintage, panel=panel, ...) )
+     TSdbi:::TSdatesSQL(serIDs, con, vintage=vintage, panel=panel) )
 
 
 setMethod("TSdescription",   signature(x="character", con="MySQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
-        TSdbi:::TSdescriptionSQL(x=x, con=con, ...) )
+        TSdbi:::TSdescriptionSQL(x=x, con=con) )
 
 setMethod("TSdoc",   signature(x="character", con="MySQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
-        TSdbi:::TSdocSQL(x=x, con=con, ...) )
+        TSdbi:::TSdocSQL(x=x, con=con) )
 
 setMethod("TSlabel",   signature(x="character", con="MySQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
-        TSdbi:::TSlabelSQL(x=x, con=con, ...) )
+        TSdbi:::TSlabelSQL(x=x, con=con) )
 
-setMethod("TSdelete", signature(serIDs="character", con="MySQLConnection"),
+setMethod("TSdelete", 
+   signature(serIDs="character", con="MySQLConnection", vintage="ANY", panel="ANY"),
    definition= function(serIDs, con=getOption("TSconnection"),  
    vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
-  TSdbi:::TSdeleteSQL(serIDs=serIDs, con=con, vintage=vintage, panel=panel, ...) )
+  TSdbi:::TSdeleteSQL(serIDs=serIDs, con=con, vintage=vintage, panel=panel) )
